SuperLU: SRC/csnode_bmod.c File Reference

SuperLU 7.0.1

Functions
csnode_bmod.c File Reference

Performs numeric block updates within the relaxed snode. More...

`#include "slu_cdefs.h"`
Include dependency graph for csnode_bmod.c:

## Functions
int | csnode_bmod (const int jcol, const int jsupno, const int fsupc, singlecomplex *dense, singlecomplex *tempv, GlobalLU_t *Glu, SuperLUStat_t *stat)
| Performs numeric block updates within the relaxed snode. More...

## Detailed Description

Copyright (c) 2003, The Regents of the University of California, through Lawrence Berkeley National Laboratory (subject to receipt of any required approvals from U.S. Dept. of Energy)

All rights reserved.

The source code is distributed under BSD license, see the file License.txt at the top-level directory.

    -- SuperLU routine (version 3.0) --
    Univ. of California Berkeley, Xerox Palo Alto Research Center,
    and Lawrence Berkeley National Lab.
    October 15, 2003

    Copyright (c) 1994 by Xerox Corporation.  All rights reserved.

    THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY
    EXPRESSED OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.

    Permission is hereby granted to use or copy this program for any
    purpose, provided the above notices are retained on all copies.
    Permission to modify the code and to distribute modified code is
    granted, provided the above notices are retained, and a notice that
    the code was modified is included with the above copyright notice.

## Function Documentation

## ◆ csnode_bmod()

int csnode_bmod | ( | const int | jcol,
|  | const int | jsupno,
|  | const int | fsupc,
|  | singlecomplex * | dense,
|  | singlecomplex * | tempv,
|  | GlobalLU_t * | Glu,
|  | SuperLUStat_t * | stat
| ) |  |

Here is the call graph for this function: